import { ref, computed } from 'vue'

/** 表格多选数据操作 */
export const useSelection = (
  /** 当表格可以多选时，所指定的数据key 默认id */
  selectId = 'id',
) => {
  /** 是否选中数据
   * true: 是
   * false: 否
   */
  const isSelected = ref<boolean>(false)
  /** 选中的数据列表 */
  const selectedList = ref([])

  /** 当前选中的所有ids数组,可根据场景自行配置id字段 */
  const selectedListIds = computed((): string[] => {
    const ids: string[] = []
    selectedList.value.forEach((item) => {
      ids.push(item[selectId])
    })
    return ids
  })

  /** 获取行数据key。用来优化table的渲染;在使用跨页多选时，该属性是必须的 */
  const getRowKeys = (row: any) => {
    return row[selectId]
  }

  /** 多选操作 */
  function selectionChange(
    /** 当前选择的所有数据 */
    rowArr: [],
  ) {
    rowArr.length === 0 ? (isSelected.value = false) : (isSelected.value = true)
    selectedList.value = rowArr
  }

  return {
    /** 是否选中数据
     * true: 是
     * false: 否
     */
    isSelected,
    /** 选中的数据列表 */
    selectedList,
    /** 当前选中的所有ids数组,可根据场景自行配置id字段 */
    selectedListIds,
    /** 多选操作 */
    selectionChange,
    /** 获取行数据key。用来优化table的渲染;在使用跨页多选时，该属性是必须的 */
    getRowKeys,
  }
}
