import { TableColumnCtx } from 'element-plus/es/components/table/src/table-column/defaults'

/** 栅格对应宽度类型 */
export type BreakPoint = 'md' | 'lg'

/** 栅格占比、偏移 */
export type Responsive = {
  /** 默认栅格占比 */
  span?: number
  /** 栅格偏移量 */
  offset?: number
}

/** 选项框数据配置 */
export type EnumProps = {
  /** 选项框显示的文字 */
  label: string
  /** 选项框对应值 */
  value: any
  /** 是否禁用此选项 */
  disabled?: boolean
  /** 当 tag 为 true 时，此选择会指定 tag 显示类型 */
  tagType?: string
  /** 为树形选择时，可通过children属性指定子选项 */
  children?: EnumProps[]
  /** 其他属性 */
  [key: string]: any
}

/** 表格列对应类型 */
export type TypeProp = 'index' | 'selection' | 'expand'

/** 输入框类型 */
export type SearchType =
  | 'input'
  | 'input-number'
  | 'select'
  | 'select-v2'
  | 'tree-select'
  | 'cascader'
  | 'cascader-selector'
  | 'date-picker'
  | 'range-picker'
  | 'time-range-picker'
  | 'time-picker'
  | 'time-select'
  | 'range-input'
  | 'switch'
  | 'slider'

/** 搜索框相关配置 */
export type SearchProps = {
  /**当前搜索框类型 */
  el: SearchType
  /** 搜索项参数，根据官方文档对应传值 */
  props?: any
  /** 普通查询是否需要blur/change事件 */
  needChange?: boolean
  /** 搜索项Key非prop属性，可通过key指定 */
  key?: string
  /** 搜索项排序（从大到小） */
  order?: number
  /** 搜索项所占列数，默认1列 */
  span?: number
  /** 搜索字段左侧偏移列数 */
  offset?: number
  /** 搜索框默认值 */
  defaultValue?: string | number | boolean | any[]
} & Partial<Record<BreakPoint, Responsive>>

/** 表格字段数据 */
export interface ColumnProps<T = any>
  extends Partial<Omit<TableColumnCtx<T>, 'children' | 'renderHeader' | 'renderCell'>> {
  /** 是否是标签展示 */
  tag?: boolean
  /** 是否参与列设置
   * true: 是
   * false: 否
   */
  joniColSetting?: boolean
  /** 是否显示在表格当中 */
  isShow?: boolean
  /** 高级搜索框是否展示
   * 默认展示
   */
  searchShow?: boolean
  /** 对应索引值 */
  rowIndex?: number
  /** 搜索项配置 */
  search?: SearchProps | undefined
  /** 枚举类型，渲染的选择值 */
  enum?: EnumProps[] | ((params?: any) => Promise<any>)
  /** 当前单元格值是否根据enum格式化
   * 默认true 数据根据enum进行格式化显示
   * false: 数据不根据enum格式化显示，enum只做选择框数据
   */
  isFilterEnum?: boolean
  /** 指定label && value对应的key值 */
  fieldNames?: {
    /** 显示值label对应字段 */
    label: string
    /** 选择值value对应字段 */
    value: string
  }
  /** 自定义表头内容渲染（tsx语法） */
  headerRender?: (row: ColumnProps) => any
  /** 自定义单元格内容渲染(tsx语法) */
  render?: (scope: { row: T }) => any
  /** 多级表头 */
  _children?: ColumnProps<T>[]
}
